
#include <DoorBellReceiver.h>
/*These are hard-coded into the modified library, here for notes only
int mySyncPeriod = 6560;
int mySyncPulse = 370;
int myPeriod = 1472;
int myShortPulse = 372;
int myLongPulse = 1100; */
const int theCode = 10128;

const byte tone1Pin=12; // pin for dial tone 1
const byte tone2Pin=13; // pin for dial tone 2
const byte hbridge1 = 8;
const byte hbridge2 = 9;
const byte recHookPin = 11;

// frequencies adopted from: https://en.wikipedia.org/wiki/Dual-tone_multi-frequency_signaling
int DTMF[14][2]={
  {941,1336}, // frequencies for touch tone 0
  {697,1209}, // frequencies for touch tone 1
  {697,1336}, // frequencies for touch tone 2
  {697,1477}, // frequencies for touch tone 3
  {770,1209}, // frequencies for touch tone 4
  {770,1336}, // frequencies for touch tone 5
  {770,1477}, // frequencies for touch tone 6
  {852,1209}, // frequencies for touch tone 7
  {852,1336}, // frequencies for touch tone 8
  {852,1477}, // frequencies for touch tone 9
  {941,1209}, // frequencies for touch tone *
  {941,1477}, // frequencies for touch tone #
  {0,0}, // pause
  {350,440}, // dial tone
};
  
  /*
Cadence of the ring tone, in tenths of a second.   
U.S. standard is 2 seconds on, four seconds off {20,40}
UK ringtone would be {4,2,4,20}
*/
const int ringCadence[] = {2000,4000};
boolean codeReceived = true;

void myCallBack(unsigned int code) {
  // Print received code
  Serial.print("Received code: ");
  Serial.println(code);
  
  if (code == theCode) {
    codeReceived = true;
  }
}

//instantiate the doorbell class
DoorBellReceiver doorbellReceiver(0, 0, myCallBack);

void setup() {
  Serial.begin(57600);
  Serial.println("Ringer Code Rev4");
  
    // Print receiver config
  doorbellReceiver.printConfig();

  pinMode(tone1Pin, OUTPUT); // Output for Tone 1
    digitalWrite(tone1Pin, LOW);
  pinMode(tone2Pin, OUTPUT); // Output for Tone 2
    digitalWrite(tone2Pin, LOW);
  pinMode(recHookPin, INPUT_PULLUP); // Input to sense receiver hook
        
  pinMode(hbridge1, OUTPUT);
    digitalWrite(hbridge1, LOW);
  pinMode(hbridge2, OUTPUT);
    digitalWrite(hbridge1, LOW);
}//End Setup

void loop() {
   if (codeReceived == true) {
    ringDaPhone();
  }
  if (digitalRead(recHookPin) == LOW && codeReceived == false) {
    dialTone(13);
  }

}

void ringDaPhone() {
  doorbellReceiver.disable();
  codeReceived = false;
  Serial.println("ringing phone!");
  unsigned long startMillis = millis();
  unsigned long duration = 0;
  digitalWrite(hbridge2, HIGH);
  
  while (duration <= ringCadence[0]) {
    delay(45);  
    digitalWrite(hbridge1, !digitalRead(hbridge1));
    digitalWrite(hbridge2, !digitalRead(hbridge2));
    duration = millis() - startMillis;
  }
  digitalWrite(hbridge1, LOW);
  digitalWrite(hbridge2, LOW);
  delay(ringCadence[1]);

  doorbellReceiver.enable();
}//end ringDaPhone()

void dialTone(byte digit) {
  delay(750);
  boolean tone1state=false;
  boolean tone2state=false;
  int tone1delay=(500000/DTMF[digit][0])-10; // calculate delay (in microseconds) for tone 1 (half of the period of one cycle). 10 is a fudge factor to raise the frequency due to sluggish timing.
  int tone2delay=(500000/DTMF[digit][1])-10; // calculate delay (in microseconds) for tone 2 (half of the period of one cycle). 10 is a fudge factor to raise the frequency due to sluggish timing.
  unsigned long tone1timer=micros();
  unsigned long tone2timer=micros();

  while(!(digitalRead(recHookPin))){
    if (codeReceived == true) {
      ringDaPhone();
    }
    if(micros()-tone1timer>tone1delay){
      tone1timer=micros(); // reset the timer
      tone1state=!tone1state; // toggle tone1state
      digitalWrite(tone1Pin, tone1state);
      }
    if(micros()-tone2timer>tone2delay){
      tone2timer=micros(); // reset the timer
      tone2state=!tone2state; // toggle tone2state
      digitalWrite(tone2Pin, tone2state);
      }
    }
    digitalWrite(tone1Pin,LOW);
    digitalWrite(tone2Pin,LOW);
}


